aboutsummaryrefslogtreecommitdiffstats
path: root/modules/calendar/e-memo-shell-migrate.c
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2009-08-12 21:29:44 +0800
committerMatthew Barnes <mbarnes@redhat.com>2009-08-12 21:29:44 +0800
commit9199f2c5b1925b6d1092738bf1a1c026e53d37f0 (patch)
treeef8107588f14a9baeba47097b9fff61b8c054057 /modules/calendar/e-memo-shell-migrate.c
parente68456f60f37d5d6e18fac95a5a9ddea2e9627fa (diff)
downloadgsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar.gz
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar.bz2
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar.lz
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar.xz
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.tar.zst
gsoc2013-evolution-9199f2c5b1925b6d1092738bf1a1c026e53d37f0.zip
Get the itip-formatter plugin working.
Diffstat (limited to 'modules/calendar/e-memo-shell-migrate.c')
-rw-r--r--modules/calendar/e-memo-shell-migrate.c19
1 files changed, 16 insertions, 3 deletions
diff --git a/modules/calendar/e-memo-shell-migrate.c b/modules/calendar/e-memo-shell-migrate.c
index 20b9fea43e..d2dce309d7 100644
--- a/modules/calendar/e-memo-shell-migrate.c
+++ b/modules/calendar/e-memo-shell-migrate.c
@@ -32,6 +32,7 @@
#include "calendar/gui/calendar-config.h"
#include "calendar/gui/calendar-config-keys.h"
+#include "shell/e-shell.h"
#define WEBCAL_BASE_URI "webcal://"
#define PERSONAL_RELATIVE_URI "system"
@@ -44,6 +45,8 @@ create_memo_sources (EShellBackend *shell_backend,
ESourceGroup **on_the_web,
ESource **personal_source)
{
+ EShell *shell;
+ EShellSettings *shell_settings;
GSList *groups;
ESourceGroup *group;
gchar *base_uri, *base_uri_proto;
@@ -53,6 +56,9 @@ create_memo_sources (EShellBackend *shell_backend,
*on_the_web = NULL;
*personal_source = NULL;
+ shell = e_shell_backend_get_shell (shell_backend);
+ shell_settings = e_shell_get_shell_settings (shell);
+
base_dir = e_shell_backend_get_config_dir (shell_backend);
base_uri = g_build_filename (base_dir, "local", NULL);
@@ -100,14 +106,21 @@ create_memo_sources (EShellBackend *shell_backend,
}
if (!*personal_source) {
- /* Create the default Person task list */
+ gchar *primary_memo_list;
+
+ /* Create the default Person memo list */
ESource *source = e_source_new (_("Personal"), PERSONAL_RELATIVE_URI);
e_source_group_add_source (*on_this_computer, source, -1);
- if (!calendar_config_get_primary_memos () && !calendar_config_get_memos_selected ()) {
+ primary_memo_list = e_shell_settings_get_string (
+ shell_settings, "cal-primary-memo-list");
+
+ if (!primary_memo_list && !calendar_config_get_memos_selected ()) {
GSList selected;
- calendar_config_set_primary_memos (e_source_peek_uid (source));
+ e_shell_settings_set_string (
+ shell_settings, "cal-primary-memo-list",
+ e_source_peek_uid (source));
selected.data = (gpointer)e_source_peek_uid (source);
selected.next = NULL;